<?php

/**
 * @version		mod_scorpion_openinghours_helper.php - 12/11/2024
 * @author		Edwin Witlox $
 * @copyright	Copyright (C) Scorpion Computers and Software, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; http://www.gnu.org/copyleft/gpl.html
 * @email		info@ScorpionComputers.nl
 */
// More info about the Joomla JDate object: https://docs.joomla.org/How_to_use_JDate
// More about PHP Date format: https://www.php.net/manual/en/datetime.format.php
// $date = Date::getInstance(); // Alias of 'new Date();' - Creates a new Date object equal to the current time.
// $currentDay = Factory::getDate()->setTimezone($SelectedTimezone)->format('l');

// no direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\Date\Date;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;

class ScorpionOpeninghoursHelper {
	// Setting up private variables to use
	private $moduleNameTech = 'mod_scorpion_openinghours';
    private $moduleNameFull = 'Scorpion Opening Hours';
    private $params;
	private $document;
	private $baseURL;
    private $moduleID;
	private $moreStyle;
	private $chosenTemplate;
	private $openingHoursList;
	private $selectedTimezone;

	public function __construct($params, $id) {
        $this->params           = $params;
        $this->moduleID         = $id;
		$this->moreStyle		= $this->params->get('moreStyle');
		$this->chosenTemplate	= substr( $this->params->get('layout', 'default'), 2);
		$this->openingHoursList	= array($this->params->get('Mondaytimes1'));
		array_push($this->openingHoursList, $this->params->get('Tuesdaytimes1'));
		array_push($this->openingHoursList, $this->params->get('Wednesdaytimes1'));
		array_push($this->openingHoursList, $this->params->get('Thursdaytimes1'));
		array_push($this->openingHoursList, $this->params->get('Fridaytimes1'));
		array_push($this->openingHoursList, $this->params->get('Saturdaytimes1'));
		array_push($this->openingHoursList, $this->params->get('Sundaytimes1'));
		$this->selectedTimezone	= $this->getUsersTimezone();
		
		// Setting default variables to use in the module
		$this->$moduleID = 'scs-opening-hours-'.$id;
		$this->document = Factory::getDocument();
		$this->baseURL = Uri::root(true);
	}

	public function addBasicCSS() {
		// Add the basic CSS file from this module
		$urlCSS = $this->baseURL.'/modules/mod_scorpion_openinghours/mod_scorpion_openinghours.css';
		$this->document->addStyleSheet($urlCSS);
		// Add the specific CSS file for this template
		$templateCSS = $this->baseURL.'/modules/mod_scorpion_openinghours/tmpl/'.$this->chosenTemplate.'.css';
		$this->document->addStylesheet($templateCSS);
	}

	// Getting the parameter values for use in the rest of the module
	public function addExtraCSS(&$extraStyle) 
	{
		// Adding style tag to the top of the HTML document for better support by browsers
		$stylelink = '<style>'."\r\n";
		$stylelink .= '/* Styling for '.$this->moduleNameFull.' */'."\r\n";
		$stylelink .= $extraStyle."\r\n";
		$stylelink .= $this->moreStyle."\r\n";
		$stylelink .= '</style>';
		$this->document->addCustomTag($stylelink);
	}

	// Adding the basic HTML code for the start and end of the module
	public function addBasicHTML($StartOrEnd, $templateName = null) {
		$htmlCode = '';
		if($StartOrEnd == 'start') {
			$htmlCode .= "\r\n".'<!-- '.$this->moduleNameFull.' - BEGIN -->'."\r\n";
			$htmlCode .= '<div id='.$this->$moduleID.' class="scs-opening-hours" data-template="'.$templateName.'">'."\r\n";
		} elseif ($StartOrEnd == 'end') {
			$htmlCode .= '</div>'."\r\n";
			$htmlCode .='<!-- '.$this->moduleNameFull.' - END -->'."\r\n";
		}
		echo $htmlCode;
	}

	// Adding the basic HTML code for the additional text at the start and/or end of the openinghours
	public function getAdditionalTextHTML($BeforeOrAfter) {
		$htmlCode = '';
		if($BeforeOrAfter == 'before') {
			if($this->params->get('useTextBefore')) {
				$htmlCode .= ''."\r\n";
				$htmlCode .= '<div>'."\r\n";
				$htmlCode .= $this->params->get('textBefore')."\r\n";
				$htmlCode .= '</div>'."\r\n";
			}
		} elseif ($BeforeOrAfter == 'after') {
			if($this->params->get('useTextAfter')) {
				$htmlCode .= ''."\r\n";
				$htmlCode .= '<div>'."\r\n";
				$htmlCode .= $this->params->get('textAfter')."\r\n";
				$htmlCode .= '</div>'."\r\n";
			}
		}
		return $htmlCode;
	}

	// If a user has a specific timezone set on the website we can use that one 
	// instead of the selected in the parameters of the module
	public function getUsersTimezone() {
		$UsersTimezone = Factory::getUser()->getParam('timezone', 'EMPTY');
		if($UsersTimezone<>'EMPTY') {
			return $UsersTimezone;
		} else {
			return $this->params->get('Timezone');
		}
	}

	// Function to return if given daynumber is current day
	public function isThisCurrentDay($dayNumber) {
		$currentDayNr = Factory::getDate()->format('N');
		if ($dayNumber == $currentDayNr) {
			return true;
		} else {
			return false;
		}
	}
	
	// Function to return a class-name if given daynumber is current day
	public function getCurrentDayOpeningtimes($dayNumber) {
		return $this->openingHoursList[$dayNumber-1];
	}

	// Function to return the openinghours of a given daynumber
	public function getCurrentDayClass($dayNumber) {
		$result = '';
		$currentDayNr = Factory::getDate()->format('N');
		if ($dayNumber == $currentDayNr) {
			if($this->params->get('HighlightToday',0)) {
				$result .= ' scs-current-day';
			}
			if ($this->areWeOpenNow()) {
				$result .= ' scs-open';
			} else {
				$result .= ' scs-closed';
			}
		}
		return $result;
	}

	// Function to determine if we are open or closed
	public function areWeOpenNow() {
		$result = false;
		$currentDayNr = Factory::getDate()->format('N');
		$currentDay = Factory::getDate()->format('l');
		$currentOpeningTime = str_replace(' ','',$this->openingHoursList[$currentDayNr-1]);
		$times = explode('-',$currentOpeningTime,99);
		$currentTime = new Date('now');
		if(strtotime($currentTime) > strtotime($times[0]) && strtotime($currentTime) < strtotime($times[1]) ) {
			$result = true;
		}

		// return $currentDay.' - '.$times[0].' - '.$times[1].' - '.$currentTime.' - '.$result;
		return $result;
	}

	// function to retrieve the full text for open or closed
	public function getOpenClosedText() {
		$result = '';
		if( strlen($this->params->get('PreOpenClosedText')) > 0 ) {
			$result .= '<span class="scs-pre-open-closed">';
			$result .= $this->params->get('PreOpenClosedText').'&nbsp;';
			$result .= '</span>';
		}
		if( $this->areWeOpenNow() ) {
			$result .= '<span class="scs-open-closed scs-open">';
			$result .= $this->params->get('OpenText');
		} else {
			$result .= '<span class="scs-open-closed scs-closed">';
			$result .= $this->params->get('ClosedText');
		}
		$result .= '</span>';
		return $result;
	}
}
